@@ -135,6 +135,11 @@ def preprocess_data(data, drop_outlier=True, target='Price_p', test_size=0.15, s
         data = data[data['TypeOfMatching_m'].isin(match_types)]
     except: pass
 
+    if 'POSTCODE_AREA' in data.columns:
+        keep_cols.append('POSTCODE')
+        keep_cols.append('POSTCODE_OUTCODE')
+        keep_cols.append('POSTCODE_AREA')
+
     data = data[keep_cols]
 
     if 'POSTCODE_AREA' not in data.columns:
@@ -214,7 +219,7 @@ def preprocess_data(data, drop_outlier=True, target='Price_p', test_size=0.15, s
         data = data.rename({'index': 'unit_indx'}, axis=1)
         data = data.reset_index()
         data = data.drop('index', axis=1)
-        
+
     data['TOTAL_FLOOR_AREA_e'] = data['TOTAL_FLOOR_AREA_e'].astype(float)
     data['FLOOR_LEVEL_e'] = data['FLOOR_LEVEL_e'].astype(float)
     data['NUMBER_HEATED_ROOMS_e'] = data['NUMBER_HEATED_ROOMS_e'].astype(float)
